Struct

FwupdJsonObject

Description [src]

struct FwupdJsonObject {
  /* No available fields */
}

A JSON object.

See also: FwupdJsonArray FwupdJsonNode.

Functions

fwupd_json_object_new

Creates a new JSON object.

since: 2.1.1

Instance methods

fwupd_json_object_add_array

Adds an array to the JSON object.

since: 2.1.1

fwupd_json_object_add_array_strv

Adds a string array to the JSON object. If the node already exists the old one is replaced.

since: 2.1.1

fwupd_json_object_add_boolean

Adds a boolean value to the JSON object.

since: 2.1.1

fwupd_json_object_add_bytes

Adds bytes to the JSON object. They will be base64 encoded as a string. If the node already exists the old one is replaced.

since: 2.1.1

fwupd_json_object_add_integer

Adds an integer value to the JSON object.

since: 2.1.1

fwupd_json_object_add_node

Adds a node to the JSON object. If the node already exists the old one is replaced.

since: 2.1.1

fwupd_json_object_add_object

Adds a different object to the JSON object.

since: 2.1.1

fwupd_json_object_add_object_map

Adds a object to the JSON object.

since: 2.1.1

fwupd_json_object_add_raw

Adds a raw value to the JSON object. If the node already exists the old one is replaced.

since: 2.1.1

fwupd_json_object_add_string

Adds a string value to the JSON object. If the node already exists the old one is replaced.

since: 2.1.1

fwupd_json_object_clear

Clears the member data for the JSON object, but does not affect the refcount.

since: 2.1.1

fwupd_json_object_get_array

Gets an array from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_boolean

Gets a boolean from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_boolean_with_default

Gets a boolean from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_integer

Gets an integer from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_integer_with_default

Gets an integer from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_key_for_index

Gets the key for a given index position.

since: 2.1.1

fwupd_json_object_get_keys

Gets all the keys from a JSON object.

since: 2.1.1

fwupd_json_object_get_node

Gets a node from a JSON object.

since: 2.1.1

fwupd_json_object_get_node_for_index

Gets the node for a given index position.

since: 2.1.1

fwupd_json_object_get_nodes

Gets all the nodes from a JSON object.

since: 2.1.1

fwupd_json_object_get_object

Gets a different object from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_size

Gets the size of the JSON object.

since: 2.1.1

fwupd_json_object_get_string

Gets a string from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_get_string_with_default

Gets a string from a JSON object. An error is returned if key is not the correct type.

since: 2.1.1

fwupd_json_object_has_node

Finds if a node exists in a JSON object.

since: 2.1.1

fwupd_json_object_ref

Increases the reference count of a JSON object.

since: 2.1.1

fwupd_json_object_to_bytes

Converts the JSON object to UTF-8 bytes.

since: 2.1.1

fwupd_json_object_to_string

Converts the JSON object to a string representation.

since: 2.1.1

fwupd_json_object_unref

Decreases the reference count of a JSON object.

since: 2.1.1