Struct
FwupdJsonObject
Description [src]
struct FwupdJsonObject {
/* No available fields */
}
A JSON object.
See also: FwupdJsonArray FwupdJsonNode.
Instance methods
fwupd_json_object_add_array_strv
Adds a string array to the JSON object. If the node already exists the old one is replaced.
since: 2.1.1
fwupd_json_object_add_bytes
Adds bytes to the JSON object. They will be base64 encoded as a string. If the node already exists the old one is replaced.
since: 2.1.1
fwupd_json_object_add_node
Adds a node to the JSON object. If the node already exists the old one is replaced.
since: 2.1.1
fwupd_json_object_add_raw
Adds a raw value to the JSON object. If the node already exists the old one is replaced.
since: 2.1.1
fwupd_json_object_add_string
Adds a string value to the JSON object. If the node already exists the old one is replaced.
since: 2.1.1
fwupd_json_object_clear
Clears the member data for the JSON object, but does not affect the refcount.
since: 2.1.1
fwupd_json_object_get_array
Gets an array from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_boolean
Gets a boolean from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_boolean_with_default
Gets a boolean from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_integer
Gets an integer from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_integer_with_default
Gets an integer from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_object
Gets a different object from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_string
Gets a string from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1
fwupd_json_object_get_string_with_default
Gets a string from a JSON object. An error is returned if key is not the correct type.
since: 2.1.1